`ddst.phi` <-
function(x, j, base = ddst.base.legendre) {
  mean(base(x,j))
}

